@@ -1,10 +1,17 @@
 from __future__ import annotations
 
 from pathlib import Path
+from typing import TYPE_CHECKING, Any
 
 from .._compat import tomllib
 
-__all__ = ["dynamic_metadata", "get_requires_for_dynamic_metadata"]
+if TYPE_CHECKING:
+    from collections.abc import Mapping
+
+__all__ = [
+    "dynamic_metadata",
+    "get_requires_for_dynamic_metadata",
+]
 
 
 def __dir__() -> list[str]:
@@ -13,7 +20,8 @@ def __dir__() -> list[str]:
 
 def dynamic_metadata(
     field: str,
-    settings: dict[str, list[str] | str] | None = None,
+    settings: dict[str, list[str] | str],
+    project: Mapping[str, Any],
 ) -> str | dict[str, str]:
     from hatch_fancy_pypi_readme._builder import build_text
     from hatch_fancy_pypi_readme._config import load_and_validate_config
@@ -33,13 +41,24 @@ def dynamic_metadata(
         pyproject_dict["tool"]["hatch"]["metadata"]["hooks"]["fancy-pypi-readme"]
     )
 
-    # Version 22.3 does not have fragment support
+    if hasattr(config, "substitutions"):
+        try:
+            # We don't have access to the version at this point
+            text = build_text(
+                config.fragments, config.substitutions, version=project["version"]
+            )
+        except TypeError:
+            # Version 23.2.0 and before don't have a version field
+            # pylint: disable-next=no-value-for-parameter
+            text = build_text(config.fragments, config.substitutions)
+    else:
+        # Version 22.3 does not have fragment support
+        # pylint: disable-next=no-value-for-parameter
+        text = build_text(config.fragments)  # type: ignore[call-arg]
+
     return {
         "content-type": config.content_type,
-        "text": build_text(config.fragments, config.substitutions)
-        if hasattr(config, "substitutions")
-        # pylint: disable-next=no-value-for-parameter
-        else build_text(config.fragments),  # type: ignore[call-arg]
+        "text": text,
     }
 
 
