@@ -105,7 +105,7 @@ def test_builder_macos_arch_extra(monkeypatch):
     archflags = "-arch arm64 -arch x86_64"
     monkeypatch.setattr(sys, "platform", "darwin")
     monkeypatch.setenv("ARCHFLAGS", archflags)
-    tmpcfg = typing.cast(CMaker, SimpleNamespace(env=os.environ.copy()))
+    tmpcfg = typing.cast("CMaker", SimpleNamespace(env=os.environ.copy()))
 
     tmpbuilder = Builder(
         settings=ScikitBuildSettings(wheel=WheelSettings()),
@@ -125,7 +125,7 @@ def test_builder_macos_arch_extra(monkeypatch):
 )
 def test_builder_get_cmake_args(monkeypatch, cmake_args, answer):
     monkeypatch.setenv("CMAKE_ARGS", cmake_args)
-    tmpcfg = typing.cast(CMaker, SimpleNamespace(env=os.environ.copy()))
+    tmpcfg = typing.cast("CMaker", SimpleNamespace(env=os.environ.copy()))
     tmpbuilder = Builder(
         settings=ScikitBuildSettings(wheel=WheelSettings()),
         config=tmpcfg,
@@ -138,7 +138,7 @@ def test_build_tool_args():
     settings = ScikitBuildSettings(build=BuildSettings(tool_args=["b"]))
     tmpbuilder = Builder(
         settings=settings,
-        config=typing.cast(CMaker, config),
+        config=typing.cast("CMaker", config),
     )
     tmpbuilder.build(["a"])
     config.build.assert_called_once_with(
@@ -172,7 +172,7 @@ def test_wheel_tag(monkeypatch, minver, archs, answer):
     assert plat == answer
 
 
-@pytest.mark.parametrize("archs", ["x86_64" "arm64" "universal2"])
+@pytest.mark.parametrize("archs", ["x86_64", "arm64", "universal2"])
 def test_wheel_build_tag(monkeypatch, archs):
     get_config_var = sysconfig.get_config_var
     monkeypatch.setattr(
@@ -251,13 +251,13 @@ def test_wheel_tag_with_abi_darwin(monkeypatch):
     else:
         assert str(tags) == "cp39-abi3-macosx_10_10_x86_64"
 
-    tags = WheelTag.compute_best(["x86_64"], py_api="cp37")
+    tags = WheelTag.compute_best(["x86_64"], py_api="cp38")
     if sys.implementation.name != "cpython":
         assert "macosx_10_10_x86_64" in str(tags)
         assert "abi3" not in str(tags)
-        assert "cp37" not in str(tags)
+        assert "cp38" not in str(tags)
     else:
-        assert str(tags) == "cp37-abi3-macosx_10_10_x86_64"
+        assert str(tags) == "cp38-abi3-macosx_10_10_x86_64"
 
     tags = WheelTag.compute_best(["x86_64"], py_api="py3")
     assert str(tags) == "py3-none-macosx_10_10_x86_64"
