@@ -1,5 +1,4 @@
 # Comparison with empty strings okay for symmetry
-# ruff: noqa: PLC1901
 
 from __future__ import annotations
 
@@ -46,12 +45,7 @@ def test_skbuild_settings_default(tmp_path: Path):
     assert settings.wheel.packages is None
     assert settings.wheel.py_api == ""
     assert not settings.wheel.expand_macos_universal_tags
-    assert settings.wheel.license_files == [
-        "LICEN[CS]E*",
-        "COPYING*",
-        "NOTICE*",
-        "AUTHORS*",
-    ]
+    assert settings.wheel.license_files is None
     assert settings.wheel.exclude == []
     assert settings.wheel.build_tag == ""
     assert settings.backport.find_python == Version("3.26.1")
@@ -395,14 +389,29 @@ def test_skbuild_settings_pyproject_toml_broken(
 
     ex = capsys.readouterr().out
     ex = re.sub(r"\x1b(\[.*?[@-~]|\].*?(\x07|\x1b\\))", "", ex)
-    assert (
-        ex.split()
-        == """\
-      ERROR: Unrecognized options in pyproject.toml:
-        tool.scikit-build.cmake.verison -> Did you mean: tool.scikit-build.cmake.version, tool.scikit-build.cmake.verbose, tool.scikit-build.cmake.define?
-        tool.scikit-build.logger -> Did you mean: tool.scikit-build.logging, tool.scikit-build.generate, tool.scikit-build.fail?
-      """.split()
-    )
+    assert ex.split() == [
+        "ERROR:",
+        "Unrecognized",
+        "options",
+        "in",
+        "pyproject.toml:",
+        "tool.scikit-build.cmake.verison",
+        "->",
+        "Did",
+        "you",
+        "mean:",
+        "tool.scikit-build.cmake.version,",
+        "tool.scikit-build.cmake.verbose,",
+        "tool.scikit-build.cmake.define?",
+        "tool.scikit-build.logger",
+        "->",
+        "Did",
+        "you",
+        "mean:",
+        "tool.scikit-build.logging,",
+        "tool.scikit-build.generate,",
+        "tool.scikit-build.search?",
+    ]
 
 
 def test_skbuild_settings_pyproject_conf_broken(
@@ -435,14 +444,27 @@ def test_skbuild_settings_pyproject_conf_broken(
     ex = capsys.readouterr().out
     # Filter terminal color codes
     ex = re.sub(r"\x1b(\[.*?[@-~]|\].*?(\x07|\x1b\\))", "", ex)
-    assert (
-        ex.split()
-        == """\
-      ERROR: Unrecognized options in config-settings:
-        cmake.verison -> Did you mean: cmake.version, cmake.verbose, cmake.define?
-        logger -> Did you mean: logging?
-      """.split()
-    )
+    assert ex.split() == [
+        "ERROR:",
+        "Unrecognized",
+        "options",
+        "in",
+        "config-settings:",
+        "cmake.verison",
+        "->",
+        "Did",
+        "you",
+        "mean:",
+        "cmake.version,",
+        "cmake.verbose,",
+        "cmake.define?",
+        "logger",
+        "->",
+        "Did",
+        "you",
+        "mean:",
+        "logging?",
+    ]
 
 
 def test_skbuild_settings_min_version_defaults_strip(
@@ -541,8 +563,8 @@ def test_skbuild_settings_pyproject_toml_envvar_defines(
         "a": "1",
         "b": "2",
         "c": "empty",
-        "d": False,
-        "e": False,
+        "d": "FALSE",
+        "e": "FALSE",
     }
 
     monkeypatch.setenv("DEFAULT", "3")
@@ -552,8 +574,8 @@ def test_skbuild_settings_pyproject_toml_envvar_defines(
         "a": "1",
         "b": "2",
         "c": "3",
-        "d": False,
-        "e": True,
+        "d": "FALSE",
+        "e": "TRUE",
     }
 
 
@@ -601,27 +623,6 @@ def test_backcompat_cmake_build_env(tmp_path: Path, monkeypatch: pytest.MonkeyPa
     assert settings_reader.settings.build.targets == ["a", "b"]
 
 
-def test_backcompat_cmake_build_both_specified(
-    tmp_path: Path, monkeypatch: pytest.MonkeyPatch
-):
-    monkeypatch.setattr(
-        scikit_build_core.settings.skbuild_read_settings, "__version__", "0.10.0"
-    )
-    pyproject_toml = tmp_path / "pyproject.toml"
-    pyproject_toml.write_text(
-        textwrap.dedent(
-            """\
-            [tool.scikit-build]
-            cmake.verbose = true
-            """
-        ),
-        encoding="utf-8",
-    )
-
-    with pytest.raises(SystemExit):
-        SettingsReader.from_file(pyproject_toml, {"build.verbose": "1"})
-
-
 def test_auto_minimum_version(tmp_path: Path, monkeypatch: pytest.MonkeyPatch):
     monkeypatch.setattr(
         scikit_build_core.settings.skbuild_read_settings, "__version__", "0.10.0"
@@ -744,13 +745,181 @@ def test_skbuild_settings_auto_cmake_warning(
 
     assert settings_reader.settings.cmake.version == SpecifierSet(">=3.15")
 
-    ex = capsys.readouterr().out
+    ex = capsys.readouterr().err
     ex = re.sub(r"\x1b(\[.*?[@-~]|\].*?(\x07|\x1b\\))", "", ex)
     print(ex)
-    assert (
-        ex.split()
-        == """\
-            WARNING: CMakeLists.txt not found when looking for minimum CMake version.
-            Report this or (and) set manually to avoid this warning. Using 3.15 as a fall-back.
-      """.split()
+    assert ex.split() == [
+        "WARNING:",
+        "CMakeLists.txt",
+        "not",
+        "found",
+        "when",
+        "looking",
+        "for",
+        "minimum",
+        "CMake",
+        "version.",
+        "Report",
+        "this",
+        "or",
+        "(and)",
+        "set",
+        "manually",
+        "to",
+        "avoid",
+        "this",
+        "warning.",
+        "Using",
+        "3.15",
+        "as",
+        "a",
+        "fall-back.",
+    ]
+
+
+def test_skbuild_settings_cmake_define_list():
+    pyproject_toml = (
+        Path(__file__).parent / "packages" / "cmake_defines" / "pyproject.toml"
     )
+
+    config_settings: dict[str, list[str] | str] = {}
+
+    settings_reader = SettingsReader.from_file(pyproject_toml, config_settings)
+    settings = settings_reader.settings
+
+    assert settings.cmake.define == {
+        "NESTED_LIST": r"Apple;Lemon\;Lime;Banana",
+        "ONE_LEVEL_LIST": "Foo;Bar;ExceptionallyLargeListEntryThatWouldOverflowTheLine;Baz",
+    }
+
+
+def test_skbuild_override_renamed(
+    tmp_path: Path, monkeypatch: pytest.MonkeyPatch
+) -> None:
+    monkeypatch.setattr(
+        scikit_build_core.settings.skbuild_read_settings, "__version__", "0.10.0"
+    )
+    pyproject_toml = tmp_path / "pyproject.toml"
+    pyproject_toml.write_text(
+        textwrap.dedent(
+            """\
+            [tool.scikit-build]
+            minimum-version = "0.7"
+            """
+        ),
+        encoding="utf-8",
+    )
+
+    settings_reader = SettingsReader.from_file(pyproject_toml, {"build.verbose": "1"})
+    assert settings_reader.settings.build.verbose
+
+    settings_reader = SettingsReader.from_file(
+        pyproject_toml, env={"SKBUILD_BUILD_VERBOSE": "TRUE"}
+    )
+    assert settings_reader.settings.build.verbose
+
+
+def test_skbuild_override_renamed_fail(
+    tmp_path: Path, monkeypatch: pytest.MonkeyPatch
+) -> None:
+    monkeypatch.setattr(
+        scikit_build_core.settings.skbuild_read_settings, "__version__", "0.10.0"
+    )
+    pyproject_toml = tmp_path / "pyproject.toml"
+    pyproject_toml.write_text(
+        textwrap.dedent(
+            """\
+            [tool.scikit-build]
+            minimum-version = "0.7"
+            build.verbose = true
+            """
+        ),
+        encoding="utf-8",
+    )
+
+    with pytest.raises(SystemExit):
+        SettingsReader.from_file(pyproject_toml)
+
+
+def test_skbuild_override_static(
+    tmp_path: Path, monkeypatch: pytest.MonkeyPatch
+) -> None:
+    monkeypatch.setattr(
+        scikit_build_core.settings.skbuild_read_settings, "__version__", "0.10.0"
+    )
+    pyproject_toml = tmp_path / "pyproject.toml"
+    pyproject_toml.write_text(
+        textwrap.dedent(
+            """\
+            [tool.scikit-build]
+            minimum-version = "0.7"
+            build.verbose = true
+            """
+        ),
+        encoding="utf-8",
+    )
+    with pytest.raises(SystemExit):
+        SettingsReader.from_file(pyproject_toml)
+
+
+def test_backcompat_cmake_build_both_specified(
+    tmp_path: Path, monkeypatch: pytest.MonkeyPatch
+):
+    monkeypatch.setattr(
+        scikit_build_core.settings.skbuild_read_settings, "__version__", "0.10.0"
+    )
+    pyproject_toml = tmp_path / "pyproject.toml"
+    pyproject_toml.write_text(
+        textwrap.dedent(
+            """\
+            [tool.scikit-build]
+            cmake.verbose = true
+            """
+        ),
+        encoding="utf-8",
+    )
+
+    settings_reader = SettingsReader.from_file(pyproject_toml, {"build.verbose": "1"})
+    assert settings_reader.settings.build.verbose
+
+
+def test_backcompat_cmake_build_both_specified_static(
+    tmp_path: Path, monkeypatch: pytest.MonkeyPatch
+):
+    monkeypatch.setattr(
+        scikit_build_core.settings.skbuild_read_settings, "__version__", "0.10.0"
+    )
+    pyproject_toml = tmp_path / "pyproject.toml"
+    pyproject_toml.write_text(
+        textwrap.dedent(
+            """\
+            [tool.scikit-build]
+            build.verbose = true
+            """
+        ),
+        encoding="utf-8",
+    )
+
+    settings_reader = SettingsReader.from_file(pyproject_toml, {"cmake.verbose": "1"})
+    assert settings_reader.settings.build.verbose
+
+
+def test_backcompat_cmake_build_targets_both_specified(
+    tmp_path: Path, monkeypatch: pytest.MonkeyPatch
+):
+    monkeypatch.setattr(
+        scikit_build_core.settings.skbuild_read_settings, "__version__", "0.10.0"
+    )
+    pyproject_toml = tmp_path / "pyproject.toml"
+    pyproject_toml.write_text(
+        textwrap.dedent(
+            """\
+            [tool.scikit-build]
+            cmake.targets = ["a", "b"]
+            """
+        ),
+        encoding="utf-8",
+    )
+
+    settings_reader = SettingsReader.from_file(pyproject_toml, {"build.targets": "c;d"})
+    assert settings_reader.settings.build.targets == ["c", "d"]
